Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildSystem ¶
type BuildSystem interface {
// Name returns the name of the build systems
Name() string
// GetBuildFile returns the buildfile for this system
GetBuildFile() string
// GetCacheDirectories returns the list of directories that can be used as build cache
GetCacheDirectories(sourceTree string, homeDir string) ([]string, error)
}
BuildSystem represents the various build systems as inferred by this engine
type GetBuildSystemsFunc ¶
type GetBuildSystemsFunc func() []BuildSystem
GetBuildSystemsFunc returns the build systems
Click to show internal directories.
Click to hide internal directories.